django\_aws\_api\_gateway\_websockets package
=============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   django_aws_api_gateway_websockets.management
   django_aws_api_gateway_websockets.migrations

Submodules
----------

django\_aws\_api\_gateway\_websockets.admin module
--------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.admin
   :members:
   :show-inheritance:
   :undoc-members:

django\_aws\_api\_gateway\_websockets.apps module
-------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.apps
   :members:
   :show-inheritance:
   :undoc-members:

django\_aws\_api\_gateway\_websockets.mixins module
---------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.mixins
   :members:
   :show-inheritance:
   :undoc-members:

django\_aws\_api\_gateway\_websockets.models module
---------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.models
   :members:
   :show-inheritance:
   :undoc-members:

django\_aws\_api\_gateway\_websockets.views module
--------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.views
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: django_aws_api_gateway_websockets
   :members:
   :show-inheritance:
   :undoc-members:
